/*
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms
 * and conditions in the IBM International Program License Agreement.
 *
 *  Copyright IBM Corporation 2003, 2004. All Rights Reserved. 
 */
package com.ibm.xtools.modeler.ui.pde.examples.events.actions;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;

import com.ibm.xtools.modeler.ui.pde.examples.events.EventsPlugin;
import com.ibm.xtools.modeler.ui.pde.examples.events.OperationEventLogger;

/**
 * This action delegate walks the selected elements and log the visited elements.
 * 
 * @see IWorkbenchWindowActionDelegate
 */
public class ToggleListener
	implements IWorkbenchWindowActionDelegate {

	/**
	 * Key for start listening menu item
	 */
	private static final String KEY_START_LISTENING = "action.startListening"; //$NON-NLS-1$

	/**
	 * Key for start listening menu item tooltip
	 */
	private static final String KEY_START_LISTENING_TOOLTIP = "action.startListeningTooltip"; //$NON-NLS-1$

	/**
	 * Key for stop listening menu item
	 */
	private static final String KEY_STOP_LISTENING = "action.stopListening"; //$NON-NLS-1$

	/**
	 * Key for stop listening menu item tooltip
	 */
	private static final String KEY_STOP_LISTENING_TOOLTIP = "action.stopListeningTooltip"; //$NON-NLS-1$

	/**
	 * Constructor
	 */
	public ToggleListener() {
		//No-op
	}

	/**
	 * Toggles listening status
	 * 
	 * @see IWorkbenchWindowActionDelegate#run
	 */
	public void run(IAction action) {

		OperationEventLogger logger = EventsPlugin.getEventLogger();
		
		if ( logger.isListening() ) {
			// Stop listening
			EventsPlugin.getEventLogger().stopListening();
		} else {
			// Start listening
			EventsPlugin.getEventLogger().startListening();	
		}
		
		/*
		 * Update the action
		 */
		updateAction(action);
	}

	/**
	 * Updates the title of the action
	 * @see IWorkbenchWindowActionDelegate#selectionChanged
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		
		/*
		 * Update the action
		 */
		updateAction(action);
	}

	/**
	 * Update the action based on current listening status
	 * @param action The action to update
	 */
	private void updateAction(IAction action) {
		
		if (EventsPlugin.getEventLogger().isListening()) {
			action.setText(EventsPlugin.getResourceString(KEY_STOP_LISTENING));
			action.setToolTipText(EventsPlugin.getResourceString(KEY_STOP_LISTENING_TOOLTIP));
		} else {
			action.setText(EventsPlugin.getResourceString(KEY_START_LISTENING));
			action.setToolTipText(EventsPlugin.getResourceString(KEY_START_LISTENING_TOOLTIP));
		}
	}

	/**
	 * @see IWorkbenchWindowActionDelegate#dispose
	 */
	public void dispose() {
		//No-op
	}

	/**
	 * @see IWorkbenchWindowActionDelegate#init
	 */
	public void init(IWorkbenchWindow windowIn) {
		//No-op
	}
}