/*
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms
 * and conditions in the IBM International Program License Agreement.
 *
 *  Copyright IBM Corporation 2003, 2004. All Rights Reserved. 
 */
package com.ibm.xtools.modeler.ui.pde.examples.properties;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.emf.ecore.EModelElement;

import com.ibm.xtools.common.core.service.AbstractProvider;
import com.ibm.xtools.common.core.service.IOperation;
import com.ibm.xtools.common.ui.services.properties.GetPropertySourceOperation;
import com.ibm.xtools.common.ui.services.properties.ICompositePropertySource;
import com.ibm.xtools.common.ui.services.properties.IPropertiesProvider;
import com.ibm.xtools.common.ui.services.properties.descriptors.CompositePropertySource;
import com.ibm.xtools.common.ui.services.properties.descriptors.CompositeSourcePropertyDescriptor;

/**
 * Example property provider - provides a annotation property for any
 * <code>EModelElement</code> object
 *  
 */
public class ExamplePropertiesProvider
	extends AbstractProvider
	implements IPropertiesProvider {

	protected static final String CATEGORY = PropertiesExamplesPlugin
		.getResourceString("category"); //$NON-NLS-1$

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.ibm.xtools.common.core.service.IProvider#provides(com.ibm.xtools.common.core.service.IOperation)
	 */
	public boolean provides(IOperation operation) {
		if (operation instanceof GetPropertySourceOperation) {

			Object object = ((GetPropertySourceOperation) operation)
				.getObject();

			if (object instanceof EModelElement)
				return true;

			return object instanceof IAdaptable
				&& ((IAdaptable) object).getAdapter(EModelElement.class) != null;

		}

		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.ibm.xtools.common.ui.internal.services.properties.IPropertiesProvider#getPropertySource(java.lang.Object)
	 */
	public ICompositePropertySource getPropertySource(Object object) {

		CompositePropertySource source = new CompositePropertySource(object,
			CATEGORY);

		EModelElement target = (EModelElement) (object instanceof EModelElement ? object
			: ((IAdaptable) object).getAdapter(EModelElement.class));

		CompositeSourcePropertyDescriptor descriptor = new ExamplePropertyDescriptor(
			target, ExamplePropertiesTable.EXAMPLE_PROPERTY);

		source.addPropertyDescriptor(descriptor);
		return source;
	}
}