/*
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms
 * and conditions in the IBM International Program License Agreement.
 *
 *  Copyright IBM Corporation 2003, 2005. All Rights Reserved. 
 */
package com.ibm.xtools.modeler.ui.pde.examples.query.actions;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.Set;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.uml2.Element;

import com.ibm.xtools.emf.query.ocl.InvalidOclExpressionException;
import com.ibm.xtools.modeler.UMLModeler;
import com.ibm.xtools.modeler.ui.pde.examples.query.QueryPlugin;

/**
 * This action delegate query user for the name of a UML type, use query APIs to
 * find the inherited members of that type, and select them.
 * 
 * @see IWorkbenchWindowActionDelegate
 */
public class SelectInheritedMember
	extends QueryActionBase {

	/**
	 * Dialogs' title
	 */
	private static final String KEY_TITLE = "selectInheritedMember.title"; //$NON-NLS-1$

	/**
	 * InputDialog message
	 */
	private static final String KEY_MESSAGE = "selectInheritedMember.inputDialog.message"; //$NON-NLS-1$

	/**
	 * InputDialog default value
	 */
	private static final String KEY_DEFAULT_VALUE = "selectInheritedMember.inputDialog.defaultValue"; //$NON-NLS-1$

	/**
	 * Error message not found query result
	 */
	private static final String KEY_NOT_FOUND_MESSAGE = "selectInheritedMember.message.notFound"; //$NON-NLS-1$

	/**
	 * Constructor
	 */
	public SelectInheritedMember() {
		super(QueryPlugin.getResourceString(KEY_TITLE), QueryPlugin
			.getResourceString(KEY_MESSAGE), QueryPlugin
			.getResourceString(KEY_DEFAULT_VALUE), QueryPlugin
			.getResourceString(KEY_NOT_FOUND_MESSAGE));
		//No-op
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.ibm.xtools.modeler.ui.pde.examples.query.actions.QueryActionBase#performQuery(org.eclipse.uml2.Element,
	 *      java.lang.String, org.eclipse.core.runtime.IProgressMonitor)
	 */
	protected Set performQuery(Element element, String value,
			IProgressMonitor monitor)
		throws InterruptedException, InvalidOclExpressionException {
		String queryString = "self.inheritedMember->select(m|m.oclIsKindOf(" + value + "))";  //$NON-NLS-1$ //$NON-NLS-2$

		Object oclResult = UMLModeler.getOclQueryHelper().evaluate( element,
			queryString, monitor);
		
		// preserve the ordering of the result of the OCL expression, because
		//   it is an OCL OrderedCollection
		Set result = new LinkedHashSet();
		if (oclResult instanceof Collection) {
			result.addAll((Collection) oclResult);
		} else if (oclResult != null) {
			result.add(oclResult);
		}
		
		return result;
	}
}