/*
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms
 * and conditions in the IBM International Program License Agreement.
 *
 *  Copyright IBM Corporation 2003, 2004. All Rights Reserved. 
 */
package com.ibm.xtools.modeler.ui.pde.examples.query.actions;

import java.util.Set;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IWorkbenchWindowActionDelegate;
import org.eclipse.uml2.Element;
import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.emf.query.conditions.eobjects.EObjectCondition;
import com.ibm.xtools.emf.query.conditions.eobjects.EObjectTypeRelationCondition;
import com.ibm.xtools.emf.query.conditions.eobjects.structuralfeatures.EObjectAttributeValueCondition;
import com.ibm.xtools.emf.query.conditions.eobjects.structuralfeatures.EObjectReferenceValueCondition;
import com.ibm.xtools.emf.query.conditions.eobjects.structuralfeatures.EStructuralFeatureValueGetter;
import com.ibm.xtools.emf.query.conditions.strings.StringValue;
import com.ibm.xtools.emf.query.ocl.InvalidOclExpressionException;
import com.ibm.xtools.modeler.UMLModeler;
import com.ibm.xtools.modeler.ui.pde.examples.query.QueryPlugin;

/**
 * This action delegate query user for the name of a type, use query APIs to
 * find the properties of that type, and select them.
 * 
 * @see IWorkbenchWindowActionDelegate
 */
public class SelectProperties
	extends QueryActionBase {

	/**
	 * Dialogs' title
	 */
	private static final String KEY_TITLE = "selectProperties.title"; //$NON-NLS-1$

	/**
	 * InputDialog message
	 */
	private static final String KEY_MESSAGE = "selectProperties.inputDialog.message"; //$NON-NLS-1$

	/**
	 * InputDialog default value
	 */
	private static final String KEY_DEFAULT_VALUE = "selectProperties.inputDialog.defaultValue"; //$NON-NLS-1$

	/**
	 * Error message not found query result
	 */
	private static final String KEY_NOT_FOUND_MESSAGE = "selectProperties.message.notFound"; //$NON-NLS-1$

	/**
	 * Constructor
	 */
	public SelectProperties() {
		super(QueryPlugin.getResourceString(KEY_TITLE), QueryPlugin
			.getResourceString(KEY_MESSAGE), QueryPlugin
			.getResourceString(KEY_DEFAULT_VALUE), QueryPlugin
			.getResourceString(KEY_NOT_FOUND_MESSAGE));
		//No-op
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.ibm.xtools.modeler.ui.pde.examples.query.actions.QueryActionBase#performQuery(org.eclipse.uml2.Element,
	 *      java.lang.String, org.eclipse.core.runtime.IProgressMonitor)
	 */
	protected Set performQuery(Element element, String value,
			IProgressMonitor monitor)
		throws InterruptedException, InvalidOclExpressionException {
		
		/*
		 * Looking for properties whose type name is the specified value
		 */
		EObjectCondition condition = new EObjectReferenceValueCondition(
			new EObjectTypeRelationCondition(UML2Package.eINSTANCE.getProperty()),
			UML2Package.eINSTANCE.getTypedElement_Type(),
			new EObjectAttributeValueCondition(
				UML2Package.eINSTANCE.getNamedElement_Name(),
				new StringValue(value),
				new EStructuralFeatureValueGetter()),
			new EStructuralFeatureValueGetter());

		return UMLModeler.getQueryHelper().executeQuery(element, condition, monitor);
	}
}