/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */


/*
 * File: CreateRealizationRule.java
 */

package com.ibm.xtools.transform.samples.modeltomodel.classtoservice.rules;

import org.eclipse.uml2.Class;
import org.eclipse.uml2.Interface;
import org.eclipse.uml2.Package;
import org.eclipse.uml2.Realization;
import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.transform.core.AbstractRule;
import com.ibm.xtools.transform.core.ITransformContext;
import com.ibm.xtools.transform.samples.modeltomodel.IsTopLevelClassCondition;
import com.ibm.xtools.transform.samples.modeltomodel.ModelUtility;
import com.ibm.xtools.transform.samples.modeltomodel.l10n.ResourceManager;
import com.ibm.xtools.transform.uml2.IsElementKindCondition;

/**
 * A rule to create a realization relationship between an interface and a class
 * implementing the interface.
 *  
 */
public class CreateRealizationRule
	extends AbstractRule {

	public static final String ID = "classtoservice.realization.rule"; //$NON-NLS-1$

	public static final String NAME = ResourceManager
		.getString("CreateRealizationRule.name"); //$NON-NLS-1$

	/**
     * Default constructor. 
     * 
     * Initializes the id and the name of the rule to
     * their default values. It also initializes it to accept only
     * a top level UML2 class as source.  A top level class is a class that
     * is contained directly by a package or a model.
     */
    public CreateRealizationRule() {
    	super(ID, NAME);
    	setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE
			.getClass_()).AND(new IsTopLevelClassCondition()));
    }
	
    /**
     * Constructor.
     * 
     * Creates an instance of the rule and initializes it to accept only
     * a top level UML2 class as source.  A top level class is a class that
     * is contained directly by a package or a model.
     * 
	 * @param id
	 *            Unique id of the rule
	 * @param name
	 *            Readable name of the rule
	 */
	public CreateRealizationRule(String id, String name) {
		super(id, name);
		setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE
			.getClass_()).AND(new IsTopLevelClassCondition()));
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.ibm.xtools.transform.uml2.internal.AbstractUMLRule#doCreate(com.ibm.xtools.transform.core.internal.engine.ITransformContext)
	 */
	protected Object createTarget(ITransformContext ruleContext) {

		Class cls = (Class) ruleContext.getSource();
		String className = cls.getName();

		Package pkg = (Package) ruleContext.getPropertyValue("targetPackage"); //$NON-NLS-1$
		Interface intface = ModelUtility.getInterfaceByName(pkg,
			"I" + className); //$NON-NLS-1$
		Class impl = ModelUtility.getClassByName(pkg, className + "Impl"); //$NON-NLS-1$
		Realization realization = null;

		// Set Realization relationship between interface and impl
		if (pkg != null && intface != null && impl != null) {
			realization = ModelUtility.getRealization(pkg, impl, intface);
			if (realization == null) {
				realization = (Realization) pkg.createOwnedMember(UML2Package.eINSTANCE.getRealization());
				realization.getClients().add(impl);
				realization.setRealizingClassifier(intface);
			}
		}

		System.out.println(ID + " is executed"); //$NON-NLS-1$

		return realization;
	}

}