/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.classtotext.console.rules;

import org.eclipse.uml2.NamedElement;
import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.transform.core.AbstractRule;
import com.ibm.xtools.transform.core.ITransformContext;
import com.ibm.xtools.transform.samples.modeltotext.l10n.ResourceManager;
import com.ibm.xtools.transform.uml2.IsElementKindCondition;

/**
 * A rule to output the name of a class.
 *  
 */
public class ClassRule extends AbstractRule {

    public static final String ID = "class2text.console.class.rule"; //$NON-NLS-1$
    public static final String NAME = ResourceManager.getString("ClassToText.classRule.name"); //$NON-NLS-1$
    
    /**
     * Default constructor.
     * 
     * Initializes the id and the name of the rule to
     * their default values. Also, initializes the rule to accept a UML
     * class as source.
     */
    public ClassRule() {
    	super(ID, NAME);
        setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE.getClass_()));
    }
    
    /**
     * Creates the rule and initializes its id and the name. Also, initializes
     * the rule to accept a UML class as source.
     * 
     * @param id Unique id of the rule
     * @param name Readable name of the rule
     */
    public ClassRule(String id, String name) {
        super(id, name);
        setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE
                .getClass_()));
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.ibm.xtools.transform.uml2.internal.AbstractUMLRule#doCreate(com.ibm.xtools.transform.core.internal.engine.ITransformContext)
     */
    protected Object createTarget(ITransformContext context) {
    	NamedElement element = (NamedElement) context.getSource();
        System.out.println("Class: " + element.getName());//$NON-NLS-1$
        return null;
    }
}
