/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.classtotext.file.rules;

import java.io.StringWriter;

import org.eclipse.core.resources.IProject;

import com.ibm.xtools.transform.core.AbstractRule;
import com.ibm.xtools.transform.core.ITransformContext;
import com.ibm.xtools.transform.samples.modeltotext.ResourceUtility;
import com.ibm.xtools.transform.samples.modeltotext.l10n.ResourceManager;


/**
 * The rule to save the results of the ClassToTextFile transformation.
 */
public class SaveOutputRule
	extends AbstractRule {
	
	public final static String ID = "com.ibm.xtools.transform.samples.class2text.file.saveoutput.rule"; //$NON-NLS-1$
	
	public final static String NAME = ResourceManager.getString("ClassToText.saveOutputRule.name"); //$NON-NLS-1$

	/**
	 * Default constructor. Initializes the id and the name of the rule to
	 * their default values.
	 */
	public SaveOutputRule() {
		super(ID, NAME);
	}

	/**
	 * Creates the rule and initializes its id and the name.
     * 
     * @param id Unique id of the rule
     * @param name Readable name of the rule
	 */
	public SaveOutputRule(String id, String name) {
		super(id, name);
	}

	/* (non-Javadoc)
	 * @see com.ibm.xtools.transform.core.AbstractRule#createTarget(com.ibm.xtools.transform.core.ITransformContext)
	 */
	protected Object createTarget(ITransformContext context) throws Exception {
		Object targetWriter = context.getPropertyValue("targetWriter");  //$NON-NLS-1$
		IProject targetProject = (IProject) context.getPropertyValue("targetProject");  //$NON-NLS-1$
		String targetFile = (String) context.getPropertyValue("targetFile");//$NON-NLS-1$
		if (targetWriter != null && targetWriter instanceof StringWriter) {
			StringWriter writer = (StringWriter) targetWriter;
			ResourceUtility.writeToProjectFile(writer, targetProject, "ClassToTextOutput", targetFile, true); //$NON-NLS-1$
		}
		
		return null;
	}

}
