/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.classtotext.file.rules;

import java.io.StringWriter;

import org.eclipse.core.resources.IProject;

import com.ibm.xtools.transform.core.AbstractRule;
import com.ibm.xtools.transform.core.ITransformContext;
import com.ibm.xtools.transform.samples.modeltotext.l10n.ResourceManager;


/**
 * 
 * Sets up the target project where the results of the ClassToTextFile
 * transformation are stored.
 */
public class SetupTargetRule
	extends AbstractRule {
	
	public final static String ID = "com.ibm.xtools.transform.samples.class2text.file.setuptarget.rule"; //$NON-NLS-1$
	public final static String NAME = ResourceManager.getString("ClassToText.setupTargetRule.name"); //$NON-NLS-1$

	/**
	 * Creates the rule and initializes its id and the name to their default
	 * values.
	 */
	public SetupTargetRule() {
		super(ID, NAME);
	}
	
	/**
	 * Creates the rule and initializes its id and the name.
     * 
     * @param id Unique id of the rule
     * @param name Readable name of the rule
	 */
	public SetupTargetRule(String id, String name) {
		super(id, name);
	}


	/* (non-Javadoc)
	 * @see com.ibm.xtools.transform.uml2.AbstractUMLRule#doCreate(com.ibm.xtools.transform.core.ITransformContext)
	 */
	protected Object createTarget(ITransformContext ruleContext) {
		IProject project = (IProject) ruleContext.getTargetContainer();
		StringWriter writer = new StringWriter();
		ruleContext.setPropertyValue("targetProject", project); //$NON-NLS-1$
		ruleContext.setPropertyValue("targetWriter", writer); //$NON-NLS-1$

		String targetFile = (String)ruleContext.getPropertyValue("targetFile");//$NON-NLS-1$
		if (null == targetFile || 0 == targetFile.length()) {
			ruleContext.setPropertyValue("targetFile", new String("class2text.txt"));//$NON-NLS-2$//$NON-NLS-1$
		}
		
		return ruleContext.getTarget();
	}

}
