/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.classtotext.file.transforms;

import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.transform.core.ITransformationDescriptor;
import com.ibm.xtools.transform.samples.modeltotext.classtotext.file.rules.ClassRule;
import com.ibm.xtools.transform.samples.modeltotext.classtotext.file.rules.OperationRule;
import com.ibm.xtools.transform.samples.modeltotext.classtotext.file.rules.ParameterRule;
import com.ibm.xtools.transform.samples.modeltotext.classtotext.file.rules.PropertyRule;
import com.ibm.xtools.transform.uml2.UMLKindTransform;

/**
 * A transform that accepts a class as source and outputs its name and the
 * names of its attributes, operations and parameters in a file.
 *  
 */
public class ClassToTextFileTransform extends UMLKindTransform {
    public static final String ID = "com.ibm.xtools.transform.samples.class2text.file"; //$NON-NLS-1$

    /**
     * Constructor.
     * 
     * @param descriptor A transformation descriptor
     */
    public ClassToTextFileTransform(ITransformationDescriptor descriptor) {
        super(descriptor);
        initializeTransform();
    }

    /**
     * @param id
     */
    public ClassToTextFileTransform(String id) {
        super(id);
        initializeTransform();
    }

    private void initializeTransform() {
        UML2Package uml2 = UML2Package.eINSTANCE;  
        
        addByKind(uml2.getClass_(), new ClassRule());
        addByKind(uml2.getProperty(), new PropertyRule());
        addByKind(uml2.getOperation(), new OperationRule());
        addByKind(uml2.getParameter(), new ParameterRule());
    }

}
