/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.statetojsp.rules;

import java.io.StringWriter;
import java.io.Writer;

import org.eclipse.core.resources.IProject;
import org.eclipse.uml2.NamedElement;
import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.transform.core.AbstractRule;
import com.ibm.xtools.transform.core.ITransformContext;
import com.ibm.xtools.transform.samples.modeltotext.ResourceUtility;
import com.ibm.xtools.transform.samples.modeltotext.l10n.ResourceManager;
import com.ibm.xtools.transform.uml2.IsElementKindCondition;


/**
 * The rule to save the JSP files resulting from the StateToJsp transformation.
 */
public class SaveOutputRule	extends AbstractRule {
	
	public final static String ID = "com.ibm.xtools.transform.samples.state2jsp.saveoutput.rule"; //$NON-NLS-1$

	public final static String NAME = ResourceManager.getString("StateToJsp.saveOutputRule.name"); //$NON-NLS-1$

	/**
	 * Default constructor. Initializes the id and the name to the default
	 * values. Also initializes the rule to accept a UML state as source.
	 */
	public SaveOutputRule() {
		super(ID, NAME);
		setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE.getState()));
	}

	/**
	 * @param id
	 * @param name
	 */
	public SaveOutputRule(String id, String name) {
		super(id, name);
		setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE.getState()));
	}

	/* (non-Javadoc)
	 * @see com.ibm.xtools.transform.core.AbstractRule#createTarget(com.ibm.xtools.transform.core.ITransformContext)
	 */
	protected Object createTarget(ITransformContext context) throws Exception {

		NamedElement element = (NamedElement) context.getSource();
		Object outputbuf = context.getPropertyValue("outputBuffer");  //$NON-NLS-1$
		if (outputbuf != null && outputbuf instanceof String) {
			Writer writer = new StringWriter();
			writer.write((String) outputbuf);
			IProject targetProject = (IProject) context.getPropertyValue("targetProject");  //$NON-NLS-1$
			String overwriteFilesFlag = (String) context.getPropertyValue("overwriteOutputFiles");  //$NON-NLS-1$
			boolean overwrite = overwriteFilesFlag.equalsIgnoreCase("true");//$NON-NLS-1$
			ResourceUtility.writeToProjectFile(writer, targetProject, "web", element.getName() + ".jsp", overwrite); //$NON-NLS-1$ //$NON-NLS-2$
		}
		
		return null;
	}

}
