/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.statetojsp.rules;

import org.eclipse.core.resources.IProject;
import org.eclipse.uml2.NamedElement;
import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.transform.core.AbstractRule;
import com.ibm.xtools.transform.core.ITransformContext;
import com.ibm.xtools.transform.samples.modeltotext.ResourceUtility;
import com.ibm.xtools.transform.samples.modeltotext.l10n.ResourceManager;
import com.ibm.xtools.transform.uml2.IsElementKindCondition;

/**
 * 
 * A rule to set up the target project where the JSP files resulting from the
 * StateToJSP transformation are stored.
 */
public class SetupTargetRule extends AbstractRule {
	
	public final static String ID = "com.ibm.xtools.transform.samples.state2jsp.setuptarget.rule"; //$NON-NLS-1$
	
	public final static String NAME = ResourceManager.getString("StateToJsp.setupTargetRule.name"); //$NON-NLS-1$

	/**
	 * Default constructor. Initializes the id and the name to the default
	 * values. Also initializes the rule to accept a UML state as source.
	 */
	public SetupTargetRule() {
		super(ID, NAME);
		setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE.getState()));
	}
	/**
	 * Constructor. Initializes the id and the name of the rule and initializes
	 * the rule to accept a UML state as source.
	 * 
	 * @param id Unique id of the rule
	 * @param name Readable name of the rule.
	 */
	public SetupTargetRule(String id, String name) {
		super(id, name);
		setAcceptCondition(new IsElementKindCondition(UML2Package.eINSTANCE.getState()));
	}


	/* (non-Javadoc)
	 * @see com.ibm.xtools.transform.uml2.AbstractUMLRule#doCreate(com.ibm.xtools.transform.core.ITransformContext)
	 */
	protected Object createTarget(ITransformContext ruleContext) {
		NamedElement element = (NamedElement) ruleContext.getSource();
		Object targetContainer = ruleContext.getTargetContainer();
		
		// If a target container is not chosen or the selected target container
		// is not a IProject, choose the project containing the source model
		// element to be the target container.
		IProject project = (targetContainer instanceof IProject) ?
				(IProject) targetContainer :
				ResourceUtility.getProject(element);
				
		ruleContext.setPropertyValue("targetProject", project); //$NON-NLS-1$
		return null;
	}

}
