/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */

package com.ibm.xtools.transform.samples.modeltotext.statetojsp.transforms;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.uml2.UML2Package;

import com.ibm.xtools.transform.core.ITransformationDescriptor;
import com.ibm.xtools.transform.samples.modeltotext.statetojsp.rules.SaveOutputRule;
import com.ibm.xtools.transform.samples.modeltotext.statetojsp.rules.SetupTargetRule;
import com.ibm.xtools.transform.samples.modeltotext.statetojsp.rules.StateRule;
import com.ibm.xtools.transform.uml2.UMLKindTransform;

/**
 * Creates a JSP file from a State in a state machine. The State needs to have
 * a stereotyped from the sample profile, ScreenFlowProfile.
 */
public class StateToJspTransform
	extends UMLKindTransform {

	public final static String ID = "com.ibm.xtools.transform.samples.state2jsp"; //$NON-NLS-1$

	/**
	 * @param descriptor The transformation descriptor
	 */
	public StateToJspTransform(ITransformationDescriptor descriptor) {
		super(descriptor);
		initialize();
	}

	/**
	 * Constructor.
	 * 
	 * @param id Unique id of the transform
	 */
	public StateToJspTransform(String id) {
		super(id);
		initialize();
	}

	private void initialize() {
		EClass stateKind = UML2Package.eINSTANCE.getState();
		
		addByKind(stateKind, new SetupTargetRule());
		addByKind(stateKind, new StateRule());
		addByKind(stateKind, new SaveOutputRule());
	}
}